<?php
/******************************************************************************
 *
 * Subrion - open source content management system
 * Copyright (C) 2014 Intelliants, LLC <http://www.intelliants.com>
 *
 * This file is part of Subrion.
 *
 * Subrion is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Subrion is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Subrion. If not, see <http://www.gnu.org/licenses/>.
 *
 *
 * @link http://www.subrion.org/
 *
 ******************************************************************************/

$iaNews = $iaCore->factoryPlugin('news', iaCore::ADMIN);

$iaDb->setTable(iaNews::getTable());

if (iaView::REQUEST_JSON == $iaView->getRequestType())
{
	switch ($pageAction)
	{
		case iaCore::ACTION_READ:

			switch ($_GET['get'])
			{
				case 'alias':
					$title = $_GET['title'];

					iaUtil::loadUTF8Functions('ascii', 'validation', 'bad', 'utf8_to_ascii');
					utf8_is_ascii($title) || $title = utf8_to_ascii($title);

					$url = $iaCore->factory('page', iaCore::FRONT)->getUrlByName('news');

					$output['url'] = $url . $iaDb->getNextId() . '-' . iaSanitize::alias($title) . '.html';

					break;

				default:
					$output = $iaNews->gridRead($_GET,
						array('title', 'alias', 'date', 'status'),
						array('status' => 'equal')
					);
			}

			break;

		case iaCore::ACTION_EDIT:
			$output = $iaNews->gridUpdate($_POST);

			break;

		case iaCore::ACTION_DELETE:
			$output = $iaNews->gridDelete($_POST);
	}

	$iaView->assign($output);
}

if (iaView::REQUEST_HTML == $iaView->getRequestType())
{
	if (iaCore::ACTION_READ == $pageAction)
	{
		$iaView->grid('_IA_URL_plugins/news/js/admin/index');
	}
	else
	{
		$entry = array(
			'lang' => $iaView->language,
			'status' => iaCore::STATUS_ACTIVE
		);

		if (iaCore::ACTION_EDIT == $pageAction)
		{
			if (!isset($iaCore->requestPath[0]))
			{
				return iaView::errorPage(iaView::ERROR_NOT_FOUND);
			}

			$id = (int)$iaCore->requestPath[0];
			$entry = $iaDb->row(iaDb::ALL_COLUMNS_SELECTION, iaDb::convertIds($id));
			if (empty($entry))
			{
				return iaView::errorPage(iaView::ERROR_NOT_FOUND);
			}
		}

		$iaCore->factory('util');

		$entry = array(
			'id' => isset($id) ? $id : 0,
			'lang' => iaUtil::checkPostParam('lang', $entry),
			'title' => iaUtil::checkPostParam('title', $entry),
			'status' => iaUtil::checkPostParam('status', $entry),
			'alias' => iaUtil::checkPostParam('alias', $entry),
			'body' => iaUtil::checkPostParam('body', $entry),
			'image' => iaUtil::checkPostParam('image', $entry),
			'date' => iaUtil::checkPostParam('date', $entry)
		);

		if (empty($entry['date']))
		{
			$entry['date'] = date(iaDb::DATETIME_FORMAT);
		}

		if (isset($_POST['save']))
		{
			$error = false;
			$messages = array();

			iaUtil::loadUTF8Functions('validation', 'bad');

			$entry['status'] = in_array($entry['status'], array(iaCore::STATUS_ACTIVE, iaCore::STATUS_INACTIVE)) ? $entry['status'] : iaCore::STATUS_INACTIVE;

			if (!array_key_exists($entry['lang'], $iaCore->languages))
			{
				$entry['lang'] = IA_LANGUAGE;
			}

			if (!utf8_is_valid($entry['title']))
			{
				$entry['title'] = utf8_bad_replace($entry['title']);
			}

			if (!utf8_is_valid($entry['body']))
			{
				$entry['body'] = utf8_bad_replace($entry['body']);
			}

			if (empty($entry['title']))
			{
				$error = true;
				$messages[] = iaLanguage::get('title_is_empty');
			}

			if (empty($entry['body']))
			{
				$error = true;
				$messages[] = iaLanguage::get('body_is_empty');
			}

			$entry['alias'] = $iaNews->titleAlias(empty($entry['alias']) ? $entry['title'] : $entry['alias']);

			if (!$error)
			{
				if (isset($_FILES['image']['tmp_name']) && $_FILES['image']['tmp_name'])
				{
					$iaPicture = $iaCore->factory('picture');

					$path = iaUtil::getAccountDir();
					$file = $_FILES['image'];
					$token = iaUtil::generateToken();
					$info = array(
						'image_width' => 800,
						'image_height' => 600,
						'thumb_width' => 250,
						'thumb_height' => 250,
						'resize_mode' => iaPicture::CROP
					);

					$entry['image'] = $iaPicture->processImage($file, $path, $token, $info);
				}

				if (iaCore::ACTION_EDIT == $pageAction)
				{
					$entry['id'] = (int)$iaCore->requestPath[0];
					$iaDb->update($entry);

					$messages[] = iaLanguage::get('saved');
					$iaCore->factory('log')->write(iaLog::ACTION_UPDATE, array('module' => 'news', 'item' => 'news', 'name' => $entry['title'], 'id' => $entry['id']));
				}
				else
				{
					$entry['id'] = $iaDb->insert($entry);
					$error = empty($entry['id']);

					if (!$error)
					{
						$messages[] = iaLanguage::get('news_added');
						$iaCore->factory('log')->write(iaLog::ACTION_CREATE, array('module' => 'news', 'item' => 'news', 'name' => $entry['title'], 'id' => $entry['id']));
					}
				}

				$iaView->setMessages($messages, ($error ? iaView::ERROR : iaView::SUCCESS));

				if (isset($_POST['goto']))
				{
					$url = IA_ADMIN_URL . 'news/';
					iaUtil::post_goto(array(
						'add' => $url . 'add/',
						'list' => $url,
						'stay' => $url . 'edit/' . $entry['id'],
					));
				}
				else
				{
					iaUtil::go_to(IA_ADMIN_URL . 'news/edit/' . $entry['id']);
				}
			}
			else
			{
				$iaView->setMessages($messages);
			}
		}

		$options = array('list' => 'go_to_list', 'add' => 'add_another_one', 'stay' => 'stay_here');
		$iaView->assign('goto', $options);

		$iaView->assign('entry', $entry);

		$iaView->display('manage');
	}
}

$iaDb->resetTable();